@@ -1,19 +1,19 @@
 // Copyright (c) Microsoft Corporation. All rights reserved.
 // Licensed under the MIT License.
 
-#include "Types.h"
 #include "DateTime.h"
+#include "Types.h"
 
 namespace graphql::mapi {
 
 DateTimeValue::DateTimeValue(const FILETIME& value)
-	: m_value{ value }
+	: m_value { value }
 {
 }
 
-service::FieldResult<response::Value> DateTimeValue::getValue(service::FieldParams&& params) const
+response::Value DateTimeValue::getValue() const
 {
-	return { response::Value { convert::datetime::to_string(m_value) } };
+	return response::Value { convert::datetime::to_string(m_value) };
 }
 
 } // namespace graphql::mapi
\ No newline at end of file
